@@ -2,6 +2,7 @@
 
 import functools
 import os
+import warnings
 
 import bokeh.io as bkio
 from bokeh.layouts import gridplot
@@ -13,7 +14,11 @@ import fontawesome.icons as fontawesome
 from pkg_resources import resource_filename
 from si_prefix import si_format
 
-__version__ = '0.0.10'
+__version__ = '0.0.11'
+
+# we don't run a comprehensive test suite and mostly in notebooks,
+# so show warnings all the time.
+warnings.simplefilter('always', DeprecationWarning)
 
 
 def with_fontawesome(f):
@@ -102,7 +107,7 @@ def show(plot):
     bkio.show(plot)
 
 
-def grid(plots, ncol=4, show=True, **kwargs):
+def grid(plots, ncol=4, display=True, **kwargs):
     """Show a grid of plots in a notebook.
 
     :param plots: a list of bokeh plots.
@@ -110,10 +115,14 @@ def grid(plots, ncol=4, show=True, **kwargs):
     :param kwargs: kwargs for bokeh `gridplot`.
 
     """
+    warnings.warn(
+        "Please use `bokeh.layout.gridplot` directly with an optional "
+        "call to `.show()`", DeprecationWarning)
+
     grid = Grid(width=ncol)
     grid.extend(plots)
     plot = gridplot(grid, **kwargs)
-    if show:
+    if display:
         show(plot)
     else:
         return plot
@@ -151,7 +160,7 @@ class InfoGraphItems(dict):
 
 
 @with_fontawesome
-def infographic(items, ncol=4, show=True, **kwargs):
+def infographic(items, **kwargs):
     """Create and infographic 'plot'.
 
     :param items: 3-tuples of (label, value, unit, icon); the label should be
@@ -159,7 +168,6 @@ def infographic(items, ncol=4, show=True, **kwargs):
         icon the name of a fontawesome icon. `value` should be numeric, it
         will be normalised by use of an SI suffix for display after which
         `unit` will be appended.
-    :param ncol: number of columns in grid of items.
     :param kwargs: kwargs for bokeh gridplot.
 
     ..note:: If `bootstrap_fontawesome` has not already been called, the
@@ -201,5 +209,4 @@ def infographic(items, ncol=4, show=True, **kwargs):
         plots.append(p)
     defaults = {'toolbar_location': None}
     defaults.update(kwargs)
-    rtn = grid(plots, ncol=ncol, show=show, **defaults)
-    return rtn
+    return gridplot(plots, **defaults)
